package com.ruoyi.ems.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ems.mapper.ElecLoadIndexMapper;
import com.ruoyi.ems.domain.ElecLoadIndex;
import com.ruoyi.ems.service.IElecLoadIndexService;

/**
 * 电力负荷设施指标Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-08-09
 */
@Service
public class ElecLoadIndexServiceImpl implements IElecLoadIndexService
{
    @Autowired
    private ElecLoadIndexMapper elecLoadIndexMapper;

    /**
     * 查询电力负荷设施指标
     * 
     * @param id 电力负荷设施指标主键
     * @return 电力负荷设施指标
     */
    @Override
    public ElecLoadIndex selectElecLoadIndexById(Long id)
    {
        return elecLoadIndexMapper.selectElecLoadIndexById(id);
    }

    /**
     * 查询电力负荷设施指标列表
     * 
     * @param admEmsElecLoadIndex 电力负荷设施指标
     * @return 电力负荷设施指标
     */
    @Override
    public List<ElecLoadIndex> selectElecLoadIndexList(ElecLoadIndex admEmsElecLoadIndex)
    {
        return elecLoadIndexMapper.selectElecLoadIndexList(admEmsElecLoadIndex);
    }

    /**
     * 新增电力负荷设施指标
     * 
     * @param admEmsElecLoadIndex 电力负荷设施指标
     * @return 结果
     */
    @Override
    public int insertElecLoadIndex(ElecLoadIndex admEmsElecLoadIndex)
    {
        return elecLoadIndexMapper.insertElecLoadIndex(admEmsElecLoadIndex);
    }

    /**
     * 修改电力负荷设施指标
     * 
     * @param admEmsElecLoadIndex 电力负荷设施指标
     * @return 结果
     */
    @Override
    public int updateElecLoadIndex(ElecLoadIndex admEmsElecLoadIndex)
    {
        return elecLoadIndexMapper.updateElecLoadIndex(admEmsElecLoadIndex);
    }

    /**
     * 批量删除电力负荷设施指标
     * 
     * @param ids 需要删除的电力负荷设施指标主键
     * @return 结果
     */
    @Override
    public int deleteElecLoadIndexByIds(Long[] ids)
    {
        return elecLoadIndexMapper.deleteElecLoadIndexByIds(ids);
    }

    /**
     * 删除电力负荷设施指标信息
     * 
     * @param id 电力负荷设施指标主键
     * @return 结果
     */
    @Override
    public int deleteElecLoadIndexById(Long id)
    {
        return elecLoadIndexMapper.deleteElecLoadIndexById(id);
    }
}
