package com.ruoyi.ems.mapper;

import java.util.List;
import com.ruoyi.ems.domain.ElecLoadIndex;

/**
 * 电力负荷设施指标Mapper接口
 * 
 * @author ruoyi
 * @date 2024-08-09
 */
public interface ElecLoadIndexMapper
{
    /**
     * 查询电力负荷设施指标
     * 
     * @param id 电力负荷设施指标主键
     * @return 电力负荷设施指标
     */
     ElecLoadIndex selectElecLoadIndexById(Long id);

    /**
     * 查询电力负荷设施指标列表
     * 
     * @param elecLoadIndex 电力负荷设施指标
     * @return 电力负荷设施指标集合
     */
     List<ElecLoadIndex> selectElecLoadIndexList(ElecLoadIndex elecLoadIndex);

    /**
     * 新增电力负荷设施指标
     * 
     * @param elecLoadIndex 电力负荷设施指标
     * @return 结果
     */
     int insertElecLoadIndex(ElecLoadIndex elecLoadIndex);

    /**
     * 修改电力负荷设施指标
     * 
     * @param elecLoadIndex 电力负荷设施指标
     * @return 结果
     */
     int updateElecLoadIndex(ElecLoadIndex elecLoadIndex);

    /**
     * 删除电力负荷设施指标
     * 
     * @param id 电力负荷设施指标主键
     * @return 结果
     */
     int deleteElecLoadIndexById(Long id);

    /**
     * 批量删除电力负荷设施指标
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteElecLoadIndexByIds(Long[] ids);
}
